@@ -10,6 +10,7 @@ from ...models.http_validation_error import HTTPValidationError
 from ...models.method_ad import MethodAD
 from ...models.method_cd import MethodCD
 from ...models.method_cpt import MethodCPT
+from ...models.method_def import MethodDEF
 from ...models.method_dp import MethodDP
 from ...models.method_dt import MethodDT
 from ...models.method_esa import MethodESA
@@ -24,13 +25,15 @@ from ...models.method_rp import MethodRP
 from ...models.method_rs import MethodRS
 from ...models.method_rws import MethodRWS
 from ...models.method_sa import MethodSA
+from ...models.method_slb import MethodSLB
 from ...models.method_spt import MethodSPT
-from ...models.method_sr import MethodSR
 from ...models.method_srs import MethodSRS
 from ...models.method_ss import MethodSS
+from ...models.method_sti import MethodSTI
 from ...models.method_svt import MethodSVT
 from ...models.method_tot import MethodTOT
 from ...models.method_tp import MethodTP
+from ...models.method_tr import MethodTR
 from ...models.method_wst import MethodWST
 from ...types import Response
 
@@ -57,6 +60,7 @@ def _parse_response(
             "MethodAD",
             "MethodCD",
             "MethodCPT",
+            "MethodDEF",
             "MethodDP",
             "MethodDT",
             "MethodESA",
@@ -71,13 +75,15 @@ def _parse_response(
             "MethodRS",
             "MethodRWS",
             "MethodSA",
+            "MethodSLB",
             "MethodSPT",
-            "MethodSR",
             "MethodSRS",
             "MethodSS",
+            "MethodSTI",
             "MethodSVT",
             "MethodTOT",
             "MethodTP",
+            "MethodTR",
             "MethodWST",
         ],
     ]
@@ -90,6 +96,7 @@ def _parse_response(
             "MethodAD",
             "MethodCD",
             "MethodCPT",
+            "MethodDEF",
             "MethodDP",
             "MethodDT",
             "MethodESA",
@@ -104,13 +111,15 @@ def _parse_response(
             "MethodRS",
             "MethodRWS",
             "MethodSA",
+            "MethodSLB",
             "MethodSPT",
-            "MethodSR",
             "MethodSRS",
             "MethodSS",
+            "MethodSTI",
             "MethodSVT",
             "MethodTOT",
             "MethodTP",
+            "MethodTR",
             "MethodWST",
         ]:
             try:
@@ -236,7 +245,7 @@ def _parse_response(
             try:
                 if not isinstance(data, dict):
                     raise TypeError()
-                response_200_type_15 = MethodAD.from_dict(data)
+                response_200_type_15 = MethodTR.from_dict(data)
 
                 return response_200_type_15
             except:  # noqa: E722
@@ -244,7 +253,7 @@ def _parse_response(
             try:
                 if not isinstance(data, dict):
                     raise TypeError()
-                response_200_type_16 = MethodRO.from_dict(data)
+                response_200_type_16 = MethodAD.from_dict(data)
 
                 return response_200_type_16
             except:  # noqa: E722
@@ -252,7 +261,7 @@ def _parse_response(
             try:
                 if not isinstance(data, dict):
                     raise TypeError()
-                response_200_type_17 = MethodINC.from_dict(data)
+                response_200_type_17 = MethodRO.from_dict(data)
 
                 return response_200_type_17
             except:  # noqa: E722
@@ -260,7 +269,7 @@ def _parse_response(
             try:
                 if not isinstance(data, dict):
                     raise TypeError()
-                response_200_type_18 = MethodSR.from_dict(data)
+                response_200_type_18 = MethodINC.from_dict(data)
 
                 return response_200_type_18
             except:  # noqa: E722
@@ -268,7 +277,7 @@ def _parse_response(
             try:
                 if not isinstance(data, dict):
                     raise TypeError()
-                response_200_type_19 = MethodIW.from_dict(data)
+                response_200_type_19 = MethodDEF.from_dict(data)
 
                 return response_200_type_19
             except:  # noqa: E722
@@ -276,7 +285,7 @@ def _parse_response(
             try:
                 if not isinstance(data, dict):
                     raise TypeError()
-                response_200_type_20 = MethodDT.from_dict(data)
+                response_200_type_20 = MethodIW.from_dict(data)
 
                 return response_200_type_20
             except:  # noqa: E722
@@ -284,7 +293,7 @@ def _parse_response(
             try:
                 if not isinstance(data, dict):
                     raise TypeError()
-                response_200_type_21 = MethodOTHER.from_dict(data)
+                response_200_type_21 = MethodDT.from_dict(data)
 
                 return response_200_type_21
             except:  # noqa: E722
@@ -292,7 +301,7 @@ def _parse_response(
             try:
                 if not isinstance(data, dict):
                     raise TypeError()
-                response_200_type_22 = MethodSRS.from_dict(data)
+                response_200_type_22 = MethodOTHER.from_dict(data)
 
                 return response_200_type_22
             except:  # noqa: E722
@@ -300,16 +309,40 @@ def _parse_response(
             try:
                 if not isinstance(data, dict):
                     raise TypeError()
-                response_200_type_23 = MethodDP.from_dict(data)
+                response_200_type_23 = MethodSRS.from_dict(data)
 
                 return response_200_type_23
             except:  # noqa: E722
                 pass
+            try:
+                if not isinstance(data, dict):
+                    raise TypeError()
+                response_200_type_24 = MethodDP.from_dict(data)
+
+                return response_200_type_24
+            except:  # noqa: E722
+                pass
+            try:
+                if not isinstance(data, dict):
+                    raise TypeError()
+                response_200_type_25 = MethodWST.from_dict(data)
+
+                return response_200_type_25
+            except:  # noqa: E722
+                pass
+            try:
+                if not isinstance(data, dict):
+                    raise TypeError()
+                response_200_type_26 = MethodSLB.from_dict(data)
+
+                return response_200_type_26
+            except:  # noqa: E722
+                pass
             if not isinstance(data, dict):
                 raise TypeError()
-            response_200_type_24 = MethodWST.from_dict(data)
+            response_200_type_27 = MethodSTI.from_dict(data)
 
-            return response_200_type_24
+            return response_200_type_27
 
         response_200 = _parse_response_200(response.json())
 
@@ -333,6 +366,7 @@ def _build_response(
             "MethodAD",
             "MethodCD",
             "MethodCPT",
+            "MethodDEF",
             "MethodDP",
             "MethodDT",
             "MethodESA",
@@ -347,13 +381,15 @@ def _build_response(
             "MethodRS",
             "MethodRWS",
             "MethodSA",
+            "MethodSLB",
             "MethodSPT",
-            "MethodSR",
             "MethodSRS",
             "MethodSS",
+            "MethodSTI",
             "MethodSVT",
             "MethodTOT",
             "MethodTP",
+            "MethodTR",
             "MethodWST",
         ],
     ]
@@ -379,6 +415,7 @@ def sync_detailed(
             "MethodAD",
             "MethodCD",
             "MethodCPT",
+            "MethodDEF",
             "MethodDP",
             "MethodDT",
             "MethodESA",
@@ -393,13 +430,15 @@ def sync_detailed(
             "MethodRS",
             "MethodRWS",
             "MethodSA",
+            "MethodSLB",
             "MethodSPT",
-            "MethodSR",
             "MethodSRS",
             "MethodSS",
+            "MethodSTI",
             "MethodSVT",
             "MethodTOT",
             "MethodTP",
+            "MethodTR",
             "MethodWST",
         ],
     ]
@@ -418,7 +457,7 @@ def sync_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSPT', 'MethodSR', 'MethodSRS', 'MethodSS', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodWST']]]
+        Response[Union[HTTPValidationError, Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDEF', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSLB', 'MethodSPT', 'MethodSRS', 'MethodSS', 'MethodSTI', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodTR', 'MethodWST']]]
     """
 
     kwargs = _get_kwargs(
@@ -447,6 +486,7 @@ def sync(
             "MethodAD",
             "MethodCD",
             "MethodCPT",
+            "MethodDEF",
             "MethodDP",
             "MethodDT",
             "MethodESA",
@@ -461,13 +501,15 @@ def sync(
             "MethodRS",
             "MethodRWS",
             "MethodSA",
+            "MethodSLB",
             "MethodSPT",
-            "MethodSR",
             "MethodSRS",
             "MethodSS",
+            "MethodSTI",
             "MethodSVT",
             "MethodTOT",
             "MethodTP",
+            "MethodTR",
             "MethodWST",
         ],
     ]
@@ -486,7 +528,7 @@ def sync(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSPT', 'MethodSR', 'MethodSRS', 'MethodSS', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodWST']]
+        Union[HTTPValidationError, Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDEF', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSLB', 'MethodSPT', 'MethodSRS', 'MethodSS', 'MethodSTI', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodTR', 'MethodWST']]
     """
 
     return sync_detailed(
@@ -510,6 +552,7 @@ async def asyncio_detailed(
             "MethodAD",
             "MethodCD",
             "MethodCPT",
+            "MethodDEF",
             "MethodDP",
             "MethodDT",
             "MethodESA",
@@ -524,13 +567,15 @@ async def asyncio_detailed(
             "MethodRS",
             "MethodRWS",
             "MethodSA",
+            "MethodSLB",
             "MethodSPT",
-            "MethodSR",
             "MethodSRS",
             "MethodSS",
+            "MethodSTI",
             "MethodSVT",
             "MethodTOT",
             "MethodTP",
+            "MethodTR",
             "MethodWST",
         ],
     ]
@@ -549,7 +594,7 @@ async def asyncio_detailed(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSPT', 'MethodSR', 'MethodSRS', 'MethodSS', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodWST']]]
+        Response[Union[HTTPValidationError, Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDEF', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSLB', 'MethodSPT', 'MethodSRS', 'MethodSS', 'MethodSTI', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodTR', 'MethodWST']]]
     """
 
     kwargs = _get_kwargs(
@@ -576,6 +621,7 @@ async def asyncio(
             "MethodAD",
             "MethodCD",
             "MethodCPT",
+            "MethodDEF",
             "MethodDP",
             "MethodDT",
             "MethodESA",
@@ -590,13 +636,15 @@ async def asyncio(
             "MethodRS",
             "MethodRWS",
             "MethodSA",
+            "MethodSLB",
             "MethodSPT",
-            "MethodSR",
             "MethodSRS",
             "MethodSS",
+            "MethodSTI",
             "MethodSVT",
             "MethodTOT",
             "MethodTP",
+            "MethodTR",
             "MethodWST",
         ],
     ]
@@ -615,7 +663,7 @@ async def asyncio(
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSPT', 'MethodSR', 'MethodSRS', 'MethodSS', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodWST']]
+        Union[HTTPValidationError, Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDEF', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSLB', 'MethodSPT', 'MethodSRS', 'MethodSS', 'MethodSTI', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodTR', 'MethodWST']]
     """
 
     return (
